Anatomy Of The Application — Glances 3.1.3 documentation

# Anatomy Of The Application

This document is meant to give an overview of the Glances interface.

Legend:

`GREEN` | `OK`
`BLUE` | `CAREFUL`
`MAGENTA` | `WARNING`
`RED` | `CRITICAL`

Note

Only stats with colored background will be shown in the alert view.

- Header
- Quick Look
- CPU
- GPU
- Load
- Memory
- Network
- Connections
- Wi-Fi
- Ports
- Disk I/O
- File System
  - RAID
- Folders
- IRQ
- Sensors
- Processes List
  - Columns display
  - Process filtering
  - Extended info
- Monitored Processes List
- Applications Monitoring Process
  - Simple AMP
  - User defined AMP
  - Embedded AMP
- events
- Docker
- Actions